@@ -35,7 +35,6 @@ class PythonMemcachedInstrumentation(AbstractInstrumentedModule):
         return method_list
 
     def call(self, module, method, wrapped, instance, args, kwargs):
-        name = self.get_wrapped_name(wrapped, instance, method)
         method_name = get_method_name(method)
         extra_data = {
             "wrapped_method": "execute",
@@ -50,5 +49,5 @@ class PythonMemcachedInstrumentation(AbstractInstrumentedModule):
         elif cache_name:
             extra_data['cache_key'] = str(cache_name)
 
-        with CaptureSpan(name, "cache.memcached", extra_data, is_async=is_async_span()):
+        with CaptureSpan("cache.memcached", extra_data, is_async=is_async_span()):
             return wrapped(*args, **kwargs)
